@@ -82,3 +82,8 @@ trace = FALSE, plot.it = FALSE , se = TRUE, silent=1,
     invisible(object)
 } ## }}}
 
+cv.folds<- function (n, folds = 10) 
+{
+    split(sample(1:n), rep(1:folds, length = n))
+}
+
